# R_Script_calculation.R: R-Code to reproduce the results of

# Ralf B. Schäfer, Nadine Gerner, Ben J. Kefford, Jes Jessen Rasmussen, Mikhail A. Beketov, Dick de Zwart, Matthias Liess, Peter C. von der Ohe (2013). 
# How to characterize chemical exposure to predict ecologic effects on aquatic communities?
# submitted to ES&T

# The code has been written by:

# Nadine Gerner
# UFZ - Helmholtz Centre for Environmental Research
# Permoserstrasse 15
# 04318 Leipzig
# GERMANY
# nadine.gerner@ufz.de

# and

# Ralf B. Schäfer
# University of Koblenz-Landau 
# Fortstraße 7 
# 76829 Landau
# GERMANY
# schaefer-ralf@uni-landau.de

# Authorship: Lines 1-790 NG & RBS; Lines 791-1170 RBS & NG

# The code has been written so that it can be applied to data 
# with the same structure as the supplementary file  'Supplement.zip':

# See README.txt for details

#############################
# Important Note			#
#############################
# Since we had no permission to fully disclose the pesticide data from the Australian study
# the first part of this script (until line 790) contains some information (i.e. data rows)
# that will differ for you, when executing the code.
# Where necessary, the code has been modified to run (a few graphics),
# and hence deviates slightly from our original code.

# For the data analysis section (lines 790 ff) all data are provided
# and the output should be the same

# Also look for comments regarding graphical output on different OS

#############################
### Setup project Structure #
#############################

rm(list=ls())

### path to project

## This has to be changed to your path!
pfad = "~/Desktop/Changed_documents/Comparison_TU_SSD/Submission/R_code_and_data/Data"
# set path without white space (replace with underscore as in example)
# and use only standard characters (a-z)
# on some computers the path may cause problems otherwise

setwd(pfad)
###########################
### Load package and data #
###########################

### Load packages
# see package installation guide for R if they are not installed
# http://cran.r-project.org/doc/manuals/R-admin.html#Installing-packages

require(plyr)
require(beanplot)

### load data
# toxicity data
data = read.table(file.path(pfad, "Toxicity_data.csv"), header=TRUE, sep="\t", dec=".", na.string="NR")
length(unique(data$TestCAS))
#107 compounds

# ModeOfAction
moa = read.table(file.path(pfad, "MOA.csv"), header=TRUE,sep="\t",dec=".")
length(unique(moa$CAS))
#103 compounds

# environmental concentrations
conc = read.table(file.path(pfad, "Concentrations.csv"), header=TRUE, sep="\t", dec=".")	
length(unique(conc$CAS))
#107 compounds
# Note: here and below some numbers will differ
# since we had no permission to fully disclose the pesticide data from the Australian study
# i.e. the data lacks the Australian raw data and several numbers will consequently be lower
# however, this does not affect the data analysis (lines 790 ff)

# TOC values
toc = read.table(file.path(pfad, "TOC.txt"), header=TRUE, sep="\t", dec=".")

# compounds and KOC values
koc = read.table(file.path(pfad, "Compounds.csv"), header=TRUE, sep="\t", dec=".")
length(unique(koc$CAS))
#107 compounds


###########################
### SSD for each compound #
###########################

#1)        log10 transformation of toxicity data (EC50)
#2)        mean EC50 per compound (= midpoint of SSD)
#3)        standard deviation sd (= slope of SSD) per MoA
#4)        standard deviation sd (= slope of SSD) per compound


nrow(data)	# 2222
head(data)

length(levels(as.factor(data$TestCAS)))		# 107 
length(levels(as.factor(data$PesticideName)))	# 107
length(levels(as.factor(data$LATINNAME)))		# 382


# only usable studies:

nrow(data[data$Plausibility=="Y", ])	# 1491
nrow(data[data$Plausibility=="N", ])	# 731   

data = data[data$Plausibility=="Y", ]
head(data)


# 1) log10 transformation of toxicity data (EC50): 

data$LOGConcentrationUgLMedian = log10(data$ConcentrationUgLMedian)
head(data)


# Normalisation / Mean Centering (only for slope, not for midpoint) : 

MeanAll = mean(data$LOGConcentrationUgLMedian)

data$NormLOGConcentrationUgLMedian = data$LOGConcentrationUgLMedian - MeanAll
head(data)


# mean EC50 per taxa-compound combination:

data$CODE = paste(data$TestCAS, data$LATINNAME, sep=",")
levels(as.factor(data$CODE))	# 992  

MeanLOGConcentrationUgLMedian = tapply(data$LOGConcentrationUgLMedian, data$CODE, mean)				
# for midpoint: non-normalised log-conc; mean = geometric mean since log(x)
MeanLOGConcentrationUgLMedian

MeanNormLOGConcentrationUgLMedian = tapply(data$NormLOGConcentrationUgLMedian, data$CODE, mean)			
# for slope: normalised log-conc; mean = geometric mean since log(x)
MeanNormLOGConcentrationUgLMedian 

TabMeans1 = as.data.frame(cbind(MeanLOGConcentrationUgLMedian, MeanNormLOGConcentrationUgLMedian ) )
head(TabMeans1)
nrow(TabMeans1)	# 992
TabMeans1$CODE = rownames (TabMeans1)


# extract CAS, species name:

Text=rownames (TabMeans1) 	
Text
length(Text)

CASlist = numeric(length(Text))	 
CASlist
for(i in 1:length(Text))
	{
	CASlist[i] = unlist(strsplit(Text[i], "\\,"))[1]
	}
TabMeans1$CAS = CASlist

Speclist = numeric(length(Text))	 
Speclist
for(i in 1:length(Text)){
Speclist[i] = unlist(strsplit(Text[i], "\\,"))[2]}
TabMeans1$Spec = Speclist

head(TabMeans1)


# number of species per compound:

Numberspecs=sort(tapply(TabMeans1$Spec,TabMeans1$CAS,length))
Numberspecs
NoSpec=as.data.frame(Numberspecs)
head(NoSpec)
nrow(NoSpec)	# 107
NoSpec$CAS <- rownames(NoSpec)
colnames(NoSpec)[1] = "SpeciesNumber"

#remove compounds without MOA

NoSpec2=merge(NoSpec, moa[ ,c(1,2,9)], by.x="CAS", by.y="CAS")
head(NoSpec2)
nrow(NoSpec2)	# 103

# merge:
head(TabMeans1)
TabA=merge(TabMeans1, NoSpec2, by.x="CAS", by.y="CAS")
head(TabA)
nrow(TabA)	# 983

sort(NoSpec2$SpeciesNumber)
#for 72 of 103 compounds not sufficient points for SSD

#2) mean EC50 per compound (= midpoint of SSD):					
# can be calculated for all compounds

midpoint = tapply(TabA$MeanLOGConcentrationUgLMedian, TabA$CAS, mean)	
TabB = data.frame(midpoint)
TabB$CAS = rownames (TabB)
nrow(TabB)	# 103
head(TabB)

# minimum EC50/most sensitive species per compound:

minimum = tapply(TabA$MeanLOGConcentrationUgLMedian, TabA$CAS, min)	
TabB$min = minimum


#3) sd (= slope of SSD) per MoA:

nrow(moa)	# 103  
head(moa)

TabC = merge(TabMeans1, moa, by.x="CAS", by.y="CAS", all.x=T)
nrow(TabC) # 992
head(TabC)
NAs = which(is.na(TabC$MOAfinal))
#exclude rows with moafinal=NA: 4 CAS

TabC[NAs, ]
TabCa <- TabC[-NAs, ]  
nrow(TabCa)	# 983

TabCb = merge(TabCa, NoSpec, by.x="CAS", by.y="CAS", all.x=T)
head(TabCb)
nrow(TabCb)	# 983


# definition of number of species required for a SSD: 

# check impact of species number on the number of available compounds for MoA and mean slope per MoA:

# define objects in global R environment:
length_vector <- c()
moa1_sl <- data.frame()
moa2_sl <- data.frame()
moa3_sl <- data.frame()
moa4_sl <- data.frame()
sds1_sl <- array()
sds2_sl <- array()
sds3_sl <- array()
sds4_sl <- array()
for(i in 1:30) {
				TabCc_slope <-TabCb[TabCb$SpeciesNumber >= i, ]
				# number of species required:
				length_vector[i] <- length(levels(as.factor(TabCc_slope$CAS)))
				moa1_sl = TabCc_slope[TabCc_slope$MOAfinal=="AChE Blocker", ]
				moa2_sl = TabCc_slope[TabCc_slope$MOAfinal=="electron transport chain", ]
				moa3_sl = TabCc_slope[TabCc_slope$MOAfinal=="Narcosis", ]
				moa4_sl = TabCc_slope[TabCc_slope$MOAfinal=="Sodium channel", ]
				sds1_sl[i] = mean(tapply(moa1_sl$MeanNormLOGConcentrationUgLMedian, moa1_sl$CAS, sd), na.rm=T)
				sds2_sl[i] = mean(tapply(moa2_sl$MeanNormLOGConcentrationUgLMedian, moa2_sl$CAS, sd), na.rm=T)
				sds3_sl[i] = mean(tapply(moa3_sl$MeanNormLOGConcentrationUgLMedian, moa3_sl$CAS, sd), na.rm=T)
				sds4_sl[i] = mean(tapply(moa4_sl$MeanNormLOGConcentrationUgLMedian, moa4_sl$CAS, sd), na.rm=T)		
				}

par(cex=2)				
plot(1:30, length_vector, xlab="No of required species for SSD", ylab="No of available compounds")	
#-> screeplot result: 4 species represents shoulder

# check impact of species number on the SD of each MoA:

plot(1:30, sds1_sl, xlab="Minimum number of species in SSD", ylab="Mean of slope", ylim=c(0,2), las=1)
points(1:30, sds2_sl, col="red", pch=17)
points(1:30, sds3_sl, col="blue", pch=18)
points(1:30, sds4_sl, col="green", pch=19)
legend("topleft", c("AChE blocker", "Electron transport chain", "Narcosis", "Sodium channel"), col=c("black", "red", "blue", "green"), pch=c(1,17,18,19))
#-> result: 6 species represents a relative robust level for most compounds and a reasonable estimate for narcosis
#Figure used in supporting information

# select minimum of 6 species for further analysis:

TabCc = TabCb[TabCb$SpeciesNumber >= 6, ]
nrow(TabCc)	 # 864
length(levels(as.factor(TabCc$CAS)))	# 31

moas = levels(as.factor(TabCc$MOAfinal))	# 4
cas = levels(as.factor(TabCc$CAS))		# 31

moa1 = TabCc[TabCc$MOAfinal=="AChE Blocker", ]
moa2 = TabCc[TabCc$MOAfinal=="electron transport chain", ]
moa3 = TabCc[TabCc$MOAfinal=="Narcosis", ]
moa4 = TabCc[TabCc$MOAfinal=="Sodium channel", ]

sds1 = tapply(moa1$MeanNormLOGConcentrationUgLMedian, moa1$CAS, sd)	
data.frame(sds1)
SD1 = mean(sds1, na.rm=T)

sds2 = tapply(moa2$MeanNormLOGConcentrationUgLMedian, moa2$CAS, sd)	
data.frame(sds2)	
SD2 = mean(sds2, na.rm=T)

sds3 = tapply(moa3$MeanNormLOGConcentrationUgLMedian, moa3$CAS, sd)	
data.frame(sds3)
SD3 = mean(sds3, na.rm=T)

sds4 = tapply(moa4$MeanNormLOGConcentrationUgLMedian, moa4$CAS, sd)	
data.frame(sds4)
SD4 = mean(sds4, na.rm=T)		
#-> sd range: "AChE Blocker" > "Sodium channel" > "Narcosis" > "electron transport chain" 

# add sds to table:

head(TabB)
TabD = merge(TabB, moa, by.x="CAS", by.y="CAS")
head(TabD)
nrow(TabD)	# 103


#4) sd per compound (= slope of SSD):

# add slope for individual compounds first:
df1 <- data.frame(sds1, cbind(row.names(sds1)))
names(df1) <- c("mean_slope", "CAS")
df2 <- data.frame(sds2, cbind(row.names(sds2)))
names(df2) <- c("mean_slope", "CAS")
df3 <- data.frame(sds3, cbind(row.names(sds3)))
names(df3) <- c("mean_slope", "CAS")
df4 <- data.frame(sds4, cbind(row.names(sds4)))
names(df4) <- c("mean_slope", "CAS")

fin_df <- rbind(df1, df2, df3, df4)
head(fin_df)

# add to existing table:
TabE = merge(TabD, fin_df, by.x="CAS", by.y="CAS", all.x=T)
head(TabE)

# assign mean slope of MoA if no individual compound slope is available from SSD calculation:
TabE[TabE$MOAfinal=="AChE Blocker" & is.na(TabE$mean_slope), "mean_slope" ] <- SD1
TabE[TabE$MOAfinal=="electron transport chain" & is.na(TabE$mean_slope), "mean_slope"] <- SD2
TabE[TabE$MOAfinal=="Narcosis" & is.na(TabE$mean_slope), "mean_slope"] <- SD3
TabE[TabD$MOAfinal=="Sodium channel" & is.na(TabE$mean_slope), "mean_slope"] <- SD4

nrow(TabE)	# 103
head(TabE)

TabE = TabE[ , c(1,2,3,12,4,11)]


# mean EC50 of D. magna for each compound (= LC50 D.magna):

head(TabMeans1)
TabMeans2 = TabMeans1[TabMeans1$Spec=="Daphnia magna", ]
head(TabMeans2)
nrow(TabMeans2)	# 107
TabF = TabMeans2 [ , c(1,4)]
head(TabF)
colnames(TabF)[1] = "MeanlogLC50D.magna"

TabG = merge(TabE, TabF, by.x="CAS", by.y="CAS")
head(TabG)
nrow(TabG)

# check how often LC50 D.magna = the most sensitive species:

MIN = TabG$min
DM = TabG$MeanlogLC50D.magna
MIN==DM
length(which(MIN==DM))				
# 60 of 103 compounds (= 58.2%) where LC50 D.magna = LC50 most sensitive species
sum(TabG$MeanlogLC50D.magna == TabG$min)
sum(TabG$midpoint == TabG$min)
sum(TabG$MeanlogLC50D.magna == TabG$midpoint )


# check if these 60 compounds have only D.magna or multiple species:

CAS_DM = as.numeric(rownames(as.data.frame(which(MIN==DM))))
head(TabA)
TabA$CAS = as.numeric(TabA$CAS)
positions = match(CAS_DM, TabA$CAS)
TabAa = TabA[positions, ]
nrow(TabAa[TabAa$SpeciesNumber==1, ])
# for 47 of the 60 compounds D.magna is the only species available 
# (for 47 compounds D.magna = midpoint = min)
# for the 13 other compounds there are 6x2, 4x3, 1x6, 1x8, 1x10 species available
# beanplot (difference between LC50D.magna and most sensitive species) for paper

par(cex=1.5)
beanplot(TabG$MeanlogLC50D.magna[TabG$MeanlogLC50D.magna!= TabG$min]-TabG$min[TabG$MeanlogLC50D.magna!= TabG$min], las=1, ylab="LC50 difference in log units")

#see Kampstra 2008 R Journal 2008, 1-9

#function to save plot (on OS with X11 device only)
#remove # to apply function
#savePlot(filename = file.path(pfad, "Difference LC50 Dmagna min"), type = "png") 

#table (for CAS with LC50 most sensitive species 10fold lower than D.magna)
TabGa=TabG[TabG$MeanlogLC50D.magna-TabG$min >1, c(1:4,7,5,6)]
nrow(TabGa)	 # 18

#function to write table
#write.table(TabGa, file.path(pfad, "min 10fold lower than Dmagna.csv"), sep=";", dec=".", row.names=FALSE)

###################
### Exposure data #
###################

# environmental concentrations
head(conc)	
nrow(conc )	# 2802

# check for duplicates:
sum(duplicated(conc))
#-> no duplicates

conc$CODE = paste(conc$Site, conc$Date, conc$CAS, sep=",")

# remove measurements that are below quantification limit:

LQL = which(conc$operator=="<")
conc = conc[-LQL, ]

nrow(conc)	# 2634
head(conc)

# TOC values
nrow(toc)	# 1444
head(toc)

# compounds and KOC values
nrow(koc)	# 107
head(koc)

# ModeOfAction
nrow(moa)	# 103
head(moa)
#-> no MoA assigned for a few compounds that were ecotoxicologically irrelevant in the measured concentrations


# merge all tables:

# conc + toc:
conc$CODE = paste(conc$Source, conc$Site, conc$Date, sep=",")
toc$CODE = paste(toc$Source, toc$Site, toc$Date, sep=",")
head(conc)
head(toc)
nrow(conc)	# 2634
nrow(toc)	# 1444

Tab2 = merge (conc, toc, by.x="CODE", by.y="CODE", all.x=TRUE)
nrow(Tab2) 	# 2634
head(Tab2)

# + koc:
head(koc)
nrow(koc)	# 107

Tab3 = merge (Tab2, koc, by.x="CAS", by.y="CAS", all.x=T)
nrow(Tab3) 	# 2634
head(Tab3)


# calculate bioavailable concentration:

Tab3$ConcBioav = Tab3$Conc / (((Tab3$TOC/1000000000) * Tab3$KOC) + 1) 			# TOC/1e09 to convert µg/L to g/L; in %
head(Tab3)

# for TRIMPS bioavailable concentration equals concentration in passive sampler
Tab3$ConcBioav[is.na(Tab3$TOC)] <- Tab3[is.na(Tab3$TOC), "Conc" ]

Tab4=merge(Tab3, moa, by.x="CAS", by.y="CAS", all.x=T)
head(Tab4)
nrow(Tab4)	# 2634

# + mean, sd per CAS:
head(TabG)
nrow(TabG)	# 103

Tab5=merge(Tab4, TabG, by.x="CAS", by.y="CAS", all.x=T)
head(Tab5)
nrow(Tab5)	# 2634
Tab5 = Tab5[ , c(1,2,3,4,7,5,6,12,14,17,18,22,26,27,28,29,32)]
Tab5[1:20, ]

# compound properties (for SI of publication):
SI_tab1 <- Tab5[ , c(1,9,10,12,13, 17, 15)]
head(SI_tab1)
SI_tab2 <- unique(SI_tab1[!is.na(SI_tab1$NumberSpecies), ])
names(SI_tab2) <- c("CAS", "Compound name", "KOC", "No. species for SSD", "MOA","Mean log LC50 D. magna", "Log LC50 most sensitive species") 
#write.table(SI_tab2, "SI_tab.csv", sep=";", dec=".", row.names=FALSE)

# check and plot number of measured compounds per site and study:

# only one row per site and date:
num_comps_dat <- ddply(Tab5[!(Tab5$Source.x=="Australien Sediment" | Tab5$Source.x=="Australien TRIMPS"), 2:5], "CODE", function(x) data.frame(x, numcompounds=nrow(x)))
num_comps_fin <- unique(num_comps_dat)
nrow(num_comps_fin)# 461

# drop unused levels:
num_comps_fin$Source.x <- factor(num_comps_fin$Source.x)

par(cex=1.7)
boxplot(numcompounds ~ Source.x, data = num_comps_fin, ylim=c(0,17), outline=FALSE, axes=FALSE)
box()
axis(1, at=1:4, labels=c("Denmark", "France", "Germany", "Spain"))
axis(2, las=1)
axis(2, las=1, at=0:17, labels=c(NA,NA,NA,NA,NA, NA,NA,NA,NA,NA, NA,NA,NA,NA,NA, NA,NA,NA), lwd=0.5)
mtext("Number of compounds in sample", side=2, line = 2.4, cex=2)

# derive HC5 assuming a lognormal distribution of the SSD:
Tab5$logHU_HC5 = (qnorm(0.05,mean=0,Tab5$mean_slope))
# arguments in function: 0.05 = quantile, mean = mean of normal distribution
# Tab5$mean_slope = standard deviation of distribution 
# 1 = select lower tail for cumulative distribution

Tab5$logHC5 = Tab5$logHU_HC5 + Tab5$midpoint		
# logHU_HC5 depends on midpoint
# adding the midpoint yields the logarithmic concentration

head(Tab5)
length(levels(as.factor(Tab5$CODE))) 	# 622

# exclude CAS with MoA=NA:

NAs = which(is.na(Tab5$MOAfinal.x))	
# 4 CAS, 43 rows
Tab5 = Tab5[-NAs,]						
# removed compounds played no role regarding maximum toxicity
#additionally, since joint PAF can not be calculated, they are removed from TU calculation

nrow(Tab5) 	 # 2593
levels(as.factor(Tab5$CODE)) 	# 610 			
# 12 CODE levels less (always only 1 CAS per CODE, but different dates exist for same site)


###########################
# TU- and PAF-calculation #
###########################


#5)         environmental concentration of individual compounds:    TU = (concentration of compound y) /(10^midpoint)
#6)         Result of TU approach: TUmax and TUsum (for the 4 approaches) per CODE
#7) 		CAed(concentration addition within same MoA) (= sum of HC50 of all compounds per MOA)
#8) 		multi-substance potentially affected fraction msPAF (= effect per MoA)
#9)         msPAF of different MoAs, response addition RA (= msPAFra)


# for each sampling site-date-method combination (= CODE):

## 4 initial methods (see figure 1)
# Dm)= LC50 D.magna
# Min)= LC50 most sensitive species/ minimum EC50 
# HC50)= HC50
# HC5)= HC5

## -> TUs approach
# TU per compound 
# TUmax per CODE
# TUsum per CODE

## -> msPAFca approach
# HUs per compound
# HUs per CODE
# CA=sum(HUs) per MoA
# RA of PAFs per MoA



## -> TUs approach

#5) environmental concentration of individual compounds:
#    TU = (concentration of compound y) /(10^midpoint)


#Dm) TU per compound, TUmax, TUsum:

Tab5$TU_Dm = Tab5$ConcBioav / (10^Tab5$MeanlogLC50D.magna)		# non-logarithmic TU

TU_Dm_max = tapply(Tab5$TU_Dm, Tab5$CODE, max)
TU_Dm_sum = tapply(Tab5$TU_Dm, Tab5$CODE, sum)
TU_Dm = as.data.frame(cbind(TU_Dm_max, TU_Dm_sum))
head(TU_Dm)
nrow(TU_Dm)	# 610 
TU_Dm$CODE = rownames (TU_Dm)


#Min) TU per compound, TUmax, TUsum:

Tab5$TU_Min = Tab5$ConcBioav / (10^Tab5$min)

TU_Min_max = tapply(Tab5$TU_Min, Tab5$CODE, max)
TU_Min_sum = tapply(Tab5$TU_Min, Tab5$CODE, sum)
TU_Min = as.data.frame(cbind(TU_Min_max, TU_Min_sum))
head(TU_Min)
nrow(TU_Min)	# 610 
TU_Min$CODE = rownames (TU_Min)


#HC50) TU per compound, TUmax, TUsum:

Tab5$TU_HC50 = Tab5$ConcBioav / (10^Tab5$midpoint) 

TU_HC50_max = tapply(Tab5$TU_HC50, Tab5$CODE, max)
TU_HC50_sum = tapply(Tab5$TU_HC50, Tab5$CODE, sum)
TU_HC50 = as.data.frame(cbind(TU_HC50_max, TU_HC50_sum))
head(TU_HC50)
nrow(TU_HC50)	# 610 
TU_HC50$CODE = rownames (TU_HC50)


#HC5) TU per compound, TUmax, TUsum:

Tab5$TU_HC5 = Tab5$ConcBioav / (10^Tab5$logHC5)  	
	
TU_HC5_max = tapply(Tab5$TU_HC5, Tab5$CODE, max)
TU_HC5_sum = tapply(Tab5$TU_HC5, Tab5$CODE, sum)
TU_HC5 = as.data.frame(cbind(TU_HC5_max, TU_HC5_sum))
head(TU_HC5)
nrow(TU_HC5)	# 610 
TU_HC5$CODE = rownames (TU_HC5)		


# number of compounds per CODE and MoA:

NoCompounds = tapply(Tab5$TU_Dm, list(Tab5$CODE, Tab5$MOAfinal.x), length)	
NoCompounds = as.data.frame(NoCompounds)
colnames (NoCompounds) [1] = "NoCompounds_AChE"
colnames (NoCompounds) [2] = "NoCompounds_ElectronTransport"
colnames (NoCompounds) [3] = "NoCompounds_Narcosis"
colnames (NoCompounds) [4] = "NoCompounds_Sodium"
NoCompounds$SummedNoCompounds = rowSums(NoCompounds, na.rm=T)
NoCompounds$CODE = rownames(NoCompounds)
head(NoCompounds)#sum


#6) Result of TU approach: TUmax and TUsum (for the 4 methods Dm, Min, HC50, HC5) per CODE:

head(Tab5)
#write.table(Tab5, file.path(pfad, "Codes_TUs.txt"))

# merge TUmax and TUsum of all approaches:

Tab_TU = merge(TU_Dm, TU_Min, by="CODE")
Tab_TU = merge(Tab_TU, TU_HC50, by="CODE")
Tab_TU = merge(Tab_TU, TU_HC5, by="CODE")

# logarithmize TUs:

Tab_TU$logTU_Dm_max = log10(Tab_TU$TU_Dm_max)
Tab_TU$logTU_Dm_sum = log10(Tab_TU$TU_Dm_sum)
Tab_TU$logTU_Min_max = log10(Tab_TU$TU_Min_max)
Tab_TU$logTU_Min_sum = log10(Tab_TU$TU_Min_sum)
Tab_TU$logTU_HC50_max = log10(Tab_TU$TU_HC50_max)
Tab_TU$logTU_HC50_sum = log10(Tab_TU$TU_HC50_sum)
Tab_TU$logTU_HC5_max = log10(Tab_TU$TU_HC5_max)
Tab_TU$logTU_HC5_sum = log10(Tab_TU$TU_HC5_sum)
head(Tab_TU)

Tab_TU1 = merge(Tab_TU, NoCompounds, by.x="CODE", by.y="CODE")
head(Tab_TU1)
#write.table(Tab_TU1, file.path(pfad, "TUmax_sum_NoCompounds_perCode.txt"))


##-> msPAF approach (only for HC50):

#7) CAed(concentration addition within same MoA) (= sum of TU of all compounds per MOA):

CAed_HC50 = tapply(Tab5$TU_HC50, list(Tab5$CODE, Tab5$MOAfinal.x), sum)	
CAed_HC50 = data.frame(CAed_HC50)
head(CAed_HC50)
CAed_HC50$CODE = rownames (CAed_HC50)


#8) multi-substance potentially affected fraction msPAF (= effect per MoA):

CAed_HC50$AChE.Blocker_PAF = pnorm(log10(CAed_HC50$AChE.Blocker), 0, SD1, 1)		
CAed_HC50$electron.transport.chain_PAF = pnorm(log10(CAed_HC50$electron.transport.chain), 0, SD2, 1)  
CAed_HC50$Narcosis_PAF = pnorm(log10(CAed_HC50$Narcosis), 0, SD3, 1)
CAed_HC50$Sodium.channel_PAF = pnorm(log10(CAed_HC50$Sodium.channel), 0, SD4, 1)

#arguments in pnorm function:
# vector of quantiles, mean, standard deviation, and select lower tail of cumulative distribution)

head(CAed_HC50)
CAed_HC50 = CAed_HC50[ , c(5,6,7,8,9)]


# 9) combine msPAFca of different MoAs:  msPAFra = 1-((1-A2)*(1-B2)*(1-C2))

CAed_HC50[is.na(CAed_HC50)] <- 1e-10 		
# set minimum in case of no concentration available: approximately 1/10 to 1/100 of lowest conc.

CAed_HC50$msPAFcaTotal_HC50 = 1-((1-CAed_HC50$AChE.Blocker_PAF)*(1-CAed_HC50$electron.transport.chain_PAF)*(1-CAed_HC50$Narcosis_PAF)*(1-CAed_HC50$Sodium.channel_PAF))
head(CAed_HC50)

CAed_All = cbind(CAed_HC50$CODE, CAed_HC50$msPAFcaTotal_HC50)
CAed_All = as.data.frame(CAed_All)
colnames (CAed_All) [1] = "CODE"
colnames (CAed_All) [2] = "msPAFcaTotal_HC50"
head(CAed_All)


# combine results of msPAFra and TU approach:

head(Tab_TU)

Tab_TU_PAFTotal = merge(Tab_TU, CAed_All, by.x="CODE" , by.y="CODE" )
nrow(Tab_TU_PAFTotal)	# 610
head(Tab_TU_PAFTotal)
str(Tab_TU_PAFTotal)

Tab_TU_PAFTotal$msPAFcaTotal_HC50 = as.numeric(as.character(Tab_TU_PAFTotal$msPAFcaTotal_HC50))


# extract study name, site name, date:

Text = Tab_TU_PAFTotal$CODE 	
Text
length(Text)

Sourcelist=numeric(length(Text))	 
Sourcelist
for(i in 1:length(Text)){
Sourcelist[i]=unlist(strsplit(Text[i], "\\,"))[1]}
Tab_TU_PAFTotal$Source = Sourcelist

Sitelist=numeric(length(Text))	 
Sitelist
for(i in 1:length(Text)){
Sitelist[i]=unlist(strsplit(Text[i], "\\,"))[2]}
Tab_TU_PAFTotal$Site = Sitelist

Datelist=numeric(length(Text))	 
Datelist
for(i in 1:length(Text)){
Datelist[i]=unlist(strsplit(Text[i], "\\,"))[3]}
Tab_TU_PAFTotal$Date = Datelist

Tab_TU_PAFTotal=Tab_TU_PAFTotal[,c(1,19:21,2:18)]

head(Tab_TU_PAFTotal)

#write.table(Tab_TU_PAFTotal, file.path(pfad, "Tab_TU_PAFTotal.txt"))


# max per site (combining sampling dates):

Tab_TU_PAFTotal$CODE1 = paste(Tab_TU_PAFTotal$Source, Tab_TU_PAFTotal$Site, sep=",")
head(Tab_TU_PAFTotal)

TU_Dm_max = tapply(Tab_TU_PAFTotal$TU_Dm_max, Tab_TU_PAFTotal$CODE1, max)
TU_Dm_sum = tapply(Tab_TU_PAFTotal$TU_Dm_sum, Tab_TU_PAFTotal$CODE1, max)
TU_Min_max = tapply(Tab_TU_PAFTotal$TU_Min_max, Tab_TU_PAFTotal$CODE1, max)
TU_Min_sum = tapply(Tab_TU_PAFTotal$TU_Min_sum, Tab_TU_PAFTotal$CODE1, max)
TU_HC50_max = tapply(Tab_TU_PAFTotal$TU_HC50_max, Tab_TU_PAFTotal$CODE1, max)
TU_HC50_sum = tapply(Tab_TU_PAFTotal$TU_HC50_sum, Tab_TU_PAFTotal$CODE1, max)
TU_HC5_max = tapply(Tab_TU_PAFTotal$TU_HC5_max, Tab_TU_PAFTotal$CODE1, max)
TU_HC5_sum = tapply(Tab_TU_PAFTotal$TU_HC5_sum, Tab_TU_PAFTotal$CODE1, max)

logTU_Dm_max = tapply(Tab_TU_PAFTotal$logTU_Dm_max, Tab_TU_PAFTotal$CODE1, max)
logTU_Dm_sum = tapply(Tab_TU_PAFTotal$logTU_Dm_sum, Tab_TU_PAFTotal$CODE1, max)
logTU_Min_max = tapply(Tab_TU_PAFTotal$logTU_Min_max, Tab_TU_PAFTotal$CODE1, max)
logTU_Min_sum = tapply(Tab_TU_PAFTotal$logTU_Min_sum, Tab_TU_PAFTotal$CODE1, max)
logTU_HC50_max = tapply(Tab_TU_PAFTotal$logTU_HC50_max, Tab_TU_PAFTotal$CODE1, max)
logTU_HC50_sum = tapply(Tab_TU_PAFTotal$logTU_HC50_sum, Tab_TU_PAFTotal$CODE1, max)
logTU_HC5_max = tapply(Tab_TU_PAFTotal$logTU_HC5_max, Tab_TU_PAFTotal$CODE1, max)
logTU_HC5_sum = tapply(Tab_TU_PAFTotal$logTU_HC5_sum, Tab_TU_PAFTotal$CODE1, max)

msPAFcaTotal_HC50 = tapply(Tab_TU_PAFTotal$msPAFcaTotal_HC50, Tab_TU_PAFTotal$CODE1, max) 

Tab_TU_PAFTotal_perSite = as.data.frame(cbind(TU_Dm_max, TU_Dm_sum, TU_Min_max, TU_Min_sum, TU_HC50_max, TU_HC50_sum, TU_HC5_max, TU_HC5_sum,     logTU_Dm_max, logTU_Dm_sum, logTU_Min_max, logTU_Min_sum, logTU_HC50_max, logTU_HC50_sum, logTU_HC5_max, logTU_HC5_sum,  msPAFcaTotal_HC50))
Tab_TU_PAFTotal_perSite$CODE1 = rownames(Tab_TU_PAFTotal_perSite)
head(Tab_TU_PAFTotal_perSite)
nrow(Tab_TU_PAFTotal_perSite)	# 139
length(levels(as.factor(Tab_TU_PAFTotal_perSite$CODE1)))	# 139


# extract study name, site name:

Text = Tab_TU_PAFTotal_perSite$CODE1	
Text
length(Text)

Sourcelist=numeric(length(Text))	 
Sourcelist
for(i in 1:length(Text)){
Sourcelist[i]=unlist(strsplit(Text[i], "\\,"))[1]}
Tab_TU_PAFTotal_perSite$Source = Sourcelist

Sitelist=numeric(length(Text))	 
Sitelist
for(i in 1:length(Text)){
Sitelist[i]=unlist(strsplit(Text[i], "\\,"))[2]}
Tab_TU_PAFTotal_perSite$Site = Sitelist

head(Tab_TU_PAFTotal_perSite)
Tab_TU_PAFTotal_perSite = Tab_TU_PAFTotal_perSite[ , c(18:20,1:17)]
head(Tab_TU_PAFTotal_perSite)

#write.table(Tab_TU_PAFTotal_perSite, file.path(pfad, "Tab_TU_PAFTotal_perSite.txt"))



################################################################################################################




###################
### Data analysis #
###################


### load data for analysis

# exposure data
Expdat <- read.table("Tab_TU_PAFTotal_perSite.txt", dec=".", header=TRUE)

# effect data
Effectdat <- read.table("Data_metaanalysis.txt", dec=".", header=TRUE)
#Data from Schäfer et al 2012 ES&T 2012, 46, (9), 5134–5142

# Combine exposure indicators with effect indicators:

head(Expdat)
nrow(Expdat)	
# 139; 
#no rows for the reference sites of GR (101, 509), ESP(LL501C715, LL519C716), FR(14,15,16)

head(Effectdat)
nrow(Effectdat)	# 102
str(Effectdat)
Effectdat$TU = as.numeric(Effectdat$TU)

final_eff <- Effectdat[ , -c(4)]
levels(factor(final_eff$Country))	
# 5 countries: Spain, Denmark, France, Germany, Australia
levels(factor(Expdat$Source))		
# 7 levels: 3 different sampling methods in Australia
head(final_eff)


# aggregation of different sampling methods for Australia data:
oz_max <- aggregate(Expdat[grep("Australien", Expdat$Source), -c(1:3)], list(Expdat$Site[grep("Australien", Expdat$Source)]), max)
nrow(oz_max) 	# 24
oz_max$Source <- "OZ"
names(oz_max)[1] <- "Site"


# combine maximum Australian and other exposure data:
final_exp <- rbind(Expdat[grep("Australien", Expdat$Source, invert=TRUE), -1], oz_max)
head(final_exp)
nrow(final_exp)	
# 94 from 102; missing: 2 GR, 4 FR, 2 ESP


# change site and country codes to allow combination of effect and exposure data:
final_exp$Source <- revalue(final_exp$Source, c("Denmark"="DK", "France"="FR", "Germany Water"="GR", "Llobregat water"="ESP"))
levels(factor(final_exp$Source))
# matching factor levels
names(final_exp)[1] <- "Country"

# combine exposure and effect data, only log-transformed data is used:
final_data <- merge(final_exp[ ,-c(3:10)], final_eff, all.y=TRUE)
head(final_data)
nrow(final_data) 		# 102


# fill NAs in data:
# for all metrics except msPAF: we set the reference sites to the minimum concentration/ 10 per study
# since data is log transformed, subtract 1 (to divide by 10):

min_list <- by(final_data[!is.na(final_data$logTU_Dm_max) , 3:10], final_data[!is.na(final_data$logTU_Dm_max), 1], function(x) (apply(x, 2, min))-1)

final_data[is.na(final_data$logTU_Dm_max) & final_data$Country=="GR", 3:10] <- min_list[["GR"]]
final_data[is.na(final_data$logTU_Dm_max) & final_data$Country=="ESP", 3:10] <- min_list[["ESP"]]
final_data[is.na(final_data$logTU_Dm_max) & final_data$Country=="FR", 3:10] <- min_list[["FR"]]

# for msPAF, we use the minimum from the computation of MoA (= 3.000000e-10):

min(final_data$msPAFcaTotal_HC50, na.rm=TRUE)
final_data[is.na(final_data$msPAFcaTotal_HC50), 11] <- 3e-11


#######################################################
# Analysis of relationship between different exposure #
# measures and effect index			  	      		#
#######################################################

# first check relationship between old and new TU calculation:
# first compute SPEAR - TUmax relationship using original data:

#FR)
#check with original exposure metric
summary.lm(model_fr_old <- lm(SPEAR ~ TU+Recovery, data= Effectdat[Effectdat$Country=="FR", ]))	
#r2 = 0.72, recovery highly significant
#Adj. r2 = 0.68, only 0.64 reported in original publication (Schäfer et al. 2007, Table 3)
#this is because SPEAR data taken from Schäfer et al 2012 ES&T 46, (9), 5134–5142.
#and were calculated slightly differently

par(mfcol=c(2,3))
plot(Effectdat$TU[Effectdat$Country=="FR"], Effectdat$SPEAR[Effectdat$Country=="FR"], xlab="maxTU old", ylab="SPEAR", main="France")
abline(coefficients(model_fr_old)[1], coefficients(model_fr_old)[2])
abline(coefficients(model_fr_old)[1]+ coefficients(model_fr_old)[3] , coefficients(model_fr_old)[2])

#DK)
#check with original exposure metric
summary.lm(model_dk_old <- lm(SPEAR ~ TU, data= Effectdat[Effectdat$Country=="DK", ]))	
# r2 = 0.61

plot(Effectdat$TU[Effectdat$Country=="DK"], Effectdat$SPEAR[Effectdat$Country=="DK"], xlab="maxTU old", ylab="SPEAR", main="Denmark")
abline(model_dk_old)


#GR)
#check with original exposure metric
summary.lm(model_gr_old <- lm(SPEAR ~ TU+Recovery, data= Effectdat[Effectdat$Country=="GR", ]))	
# r2 = 0.75, recovery not statistically significant, but p=0.06

plot(Effectdat$TU[Effectdat$Country=="GR"], Effectdat$SPEAR[Effectdat$Country=="GR"], xlab="maxTU old", ylab="SPEAR", main="Germany")
abline(coefficients(model_gr_old)[1], coefficients(model_gr_old)[2])
abline(coefficients(model_gr_old)[1]+ coefficients(model_gr_old)[3] , coefficients(model_gr_old)[2])


#ESP)
#check with original exposure metric
summary.lm(model_esp_old <- lm(SPEAR ~ TU+Recovery, data= Effectdat[Effectdat$Country=="ESP", ]))
#r2 = 0.89

plot(Effectdat$TU[Effectdat$Country=="ESP"], Effectdat$SPEAR[Effectdat$Country=="ESP"], xlab="maxTU old", ylab="SPEAR", main="Spain")
abline(coefficients(model_esp_old)[1], coefficients(model_esp_old)[2])
abline(coefficients(model_esp_old)[1]+ coefficients(model_esp_old)[3] , coefficients(model_esp_old)[2])


#AUS)
#check with original exposure metric
summary.lm(model_aus_old <- lm(SPEAR ~ TU, data= Effectdat[row.names(Effectdat) != "102" & Effectdat$Country=="OZ", ]))	
# r2 = 0.68, outlier removed (see Schäfer et al. 2011)
summary.lm(lm(SPEAR ~ TU, data= Effectdat[ Effectdat$Country=="OZ", ]))	
# r2 = 0.52 when including outlier

plot(Effectdat$TU[Effectdat$Country=="OZ"], Effectdat$SPEAR[Effectdat$Country=="OZ"], xlab="maxTU old", ylab="SPEAR", main="Oz")
abline(model_aus_old)
# note: plot includes outlies

#dev.copy2pdf(device="quartz", out.type= "pdf")


##########################################
# Compare TU new and old (TUmax D.magna) #
##########################################

test <-  merge(final_data[ ,c(1:3)], Effectdat, all=T)
head(test)
nrow(test) # 102
str(test)
test$TU = as.numeric(test$TU)

# plot TUnew vs. TUold:
par(mfrow=c(2,3), cex=1.5, las=1)
plot(test$logTU_Dm_max[test$Country=="DK"], test$TU[test$Country=="DK"], xlab="maxTU new", ylab="maxTU old", main="Denmark", ylim= c(-5,0), xlim=c(-6.5,0))
abline(a=0, b=1, lwd=2)
plot(test$logTU_Dm_max[test$Country=="GR"], test$TU[test$Country=="GR"], xlab="maxTU new", ylab="maxTU old", main="Germany", ylim= c(-5,0), xlim=c(-6.5,0))
abline(a=0, b=1,lwd=2)
plot(test$logTU_Dm_max[test$Country=="FR"], test$TU[test$Country=="FR"], xlab="maxTU new", ylab="maxTU old", main="France", ylim= c(-5,0), xlim=c(-6.5,0))
abline(a=0, b=1,lwd=2)
plot(test$logTU_Dm_max[test$Country=="OZ"], test$TU[test$Country=="OZ"], xlab="maxTU new", ylab="maxTU old", main="Australia", ylim= c(-5,0), xlim=c(-6.5,0))
abline(a=0, b=1,lwd=2)
plot(test$logTU_Dm_max[test$Country=="ESP"], test$TU[test$Country=="ESP"], xlab="maxTU new", ylab="maxTU old", main="Spain", ylim= c(-5,0), xlim=c(-6.5,0))
abline(a=0, b=1,lwd=2)
#-> slight general increase for Spain


# check numerically:
test$diff <- abs(test$logTU_Dm_max-test$TU)
test[test$diff > 0.15, c(1,2,3,5,7)]
#-> differences for Australia mainly due to other EC50


# compute correlation coefficients for TU old and new:
cor(test$logTU_Dm_max[test$Country=="DK"],test$TU[test$Country=="DK"])	
	# r = 0.98 
cor(test$logTU_Dm_max[test$Country=="GR"],test$TU[test$Country=="GR"])	
	# r = 0.98 
cor(test$logTU_Dm_max[test$Country=="OZ"],test$TU[test$Country=="OZ"])	
	# r = 0.98 
cor(test$logTU_Dm_max[test$Country=="FR"],test$TU[test$Country=="FR"])	
	# r = 0.99 
cor(test$logTU_Dm_max[test$Country=="ESP"],test$TU[test$Country=="ESP"])	
	# r = 0.96 


######################################################
# Modeling of relationships between exposure metrics #
# and effects data		   	   		     #
######################################################

# drop unused levels:
final_data$Country <- factor(final_data$Country)

# use logarithmic relationship for msPAF:
final_data$log_msPAF_HC50 <- log10(final_data$msPAFcaTotal_HC50)

# rearrange order:
final_data <- final_data[ ,c(1:10,14,12,13)]

# check intercorrelation between metrics across studies:
cor_table <- cor(final_data[ ,-c(1:2,12:13)])
# all correlations > 0.8
#write.table(cor_table, "intercor_table.csv", row.names=TRUE, sep=";")

# extract variable names:
name_list <- names(final_data[ ,3:11])

# create data.frame:
resdat <- data.frame(matrix(ncol=10, nrow=1))
names(resdat) <- c("Country", "Model", "Est_Intercept", "Est_Var", "Est_Recovery", "p_val_Intercept", "p_val_Var", "p_value_Recovery", "r2", "BIC")

#Note: you have to set graphics device below in function!
for (j in 1: length(levels(final_data$Country)))
		{	
		setwd(paste(pfad,"/Plots/", sep=""))
		pdf(paste0(levels(final_data$Country)[j], ".pdf"), width=8, height=12)
		par(mfrow=c(4,3))
		#make sure the sub folder Plots exists!
		for(i in 1:length(name_list))
			{
				mod <- lm(as.formula(paste(paste("SPEAR", name_list[i], sep="~"), "Recovery", sep="+")), data=final_data[final_data$Country==levels(final_data$Country)[j], ])
				resdat[i+(j-1)*length(name_list), ] <- c(levels(final_data$Country)[j], paste(name_list[i], "Recovery", sep=" + "), coef(summary(mod))[1:3,1], coef(summary(mod))[1:3,4], summary(mod)$r.squared, BIC(mod))
				plot(final_data[final_data$Country==levels(final_data$Country)[j], paste(name_list[i])], final_data$SPEAR[final_data$Country==levels(final_data$Country)[j]], xlab=paste(name_list[i]), ylab="SPEAR", main=paste(levels(final_data$Country)[j]))
				}
		dev.off()
		}


# set old wd!
setwd(pfad)

# conduct analysis without Recovery:
# create data.frame:

resdat2 <- data.frame(matrix(ncol=8, nrow=1))
names(resdat2) <- c("Country", "Model", "Est_Intercept", "Est_Var", "p_val_Intercept", "p_val_Var", "r2", "BIC")

for (j in 1: length(levels(final_data$Country)))
		{		
		for(i in 1:length(name_list))
				{
				mod <- lm(as.formula(paste("SPEAR", name_list[i], sep="~")), data=final_data[final_data$Country==levels(final_data$Country)[j], ])
				resdat2[i+(j-1)*length(name_list), ] <- c(levels(final_data$Country)[j], name_list[i], coef(summary(mod))[1:2,1], coef(summary(mod))[1:2,4], summary(mod)$r.squared, BIC(mod))
				}
		}


# combine final data:
findata <- rbind.fill(resdat2, resdat)
#write.table(findata, "Results_table.csv", sep=";", dec=".", row.names=FALSE)


# convert character to numeric or factor, where necessary:
findata[ ,3:10] <- sapply(findata[ ,3:10], as.numeric)
findata[ ,1] <- sapply(findata[ ,1], factor)


# Check whether recovery is needed in models: 	
# this is done with the rank sums and a Wilcoxon test based on the BIC ranking

# create grouping variable for recovery:
findata$Rec_included <- !is.na(findata$Est_Recovery)

# check ranks:
by(findata, findata$Country, function(x) sum(rank(x$BIC)[x$Rec_included==FALSE])/sum(1:(length(x$BIC))))
#-> lower than average ranks for Denmark and almost even for Spain
# since lower ranks means better BIC, recovery not included for Denmark and Spain

wilcox_findata <- by(findata, findata$Country, function(x) wilcox.test(x$BIC[x$Rec_included==FALSE], x$BIC[x$Rec_included==TRUE]))
#-> test not statistically significant for Germany(p = 0.14) and Spain (p = 0.97)
# but for all other countries (France and Denmark p = 0.03 and 0.02, respectively and Australia p < 0.001)
#-> however, since in original publication recovery was used in Germany and among the 8 best models 6 included recovery, recovery is also kept for Germany


#############################################
# Analyse data combined after			  #
# removing results for recovery/no recovery #
#############################################

finsub <- with(findata , findata[(Country=="DK"& Rec_included==FALSE) | (Country=="ESP"& Rec_included==FALSE) | (Country=="GR"& Rec_included==TRUE) | (Country=="FR"& Rec_included==TRUE) | (Country=="OZ"& Rec_included==TRUE), ])
# now ranks for the individual methods can be calculated for each country


# extract model for aggregation:
temp_1 <- strsplit(finsub$Model, " ")
finsub$Model_type <- unlist(temp_1)[unlist(temp_1) != "+" & unlist(temp_1) != "Recovery"]
finsub$Model_type <- factor(finsub$Model_type)

finsub$ranking <- unlist(by(finsub$BIC, finsub$Country, rank))
temp_2 <- by(finsub$ranking, finsub$Model_type, sum)
subresults <- as.data.frame(temp_2[1:length(temp_2)])
subresults[order(subresults), ]
#-> log TU for HC5 sum yields best result
#closely followed by log TU for most sensitive and log TU DM


# check methods within BIC of 2 (Burnham and Anderson, page 446):

bic_subset <- with(finsub, finsub[(Country=="DK"& BIC < min(BIC[Country=="DK"])+2)|(Country=="ESP"& BIC < min(BIC[Country=="ESP"])+2)|(Country=="GR"& BIC < min(BIC[Country=="GR"])+2)|(Country=="FR"& BIC < min(BIC[Country=="FR"])+2)| (Country=="OZ"& BIC < min(BIC[Country=="OZ"])+2), ]  )

with(bic_subset, by(bic_subset$r2, bic_subset$Country,  function(x) max(x)-min(x)))
	#-> Denmark exhibits 4% difference in r2, other countries 2% or less

bic_sub_res <- table(bic_subset$Model_type)
bic_sub_res[order(bic_sub_res)]
#-> same picture: logTU HC5 in 4 models, TU_min and TU_DM_sum in 3, log TU_DM_max in 2 and others in 1  (msPAF, TU_HC50)

# for overview Table - range of SPEAR values:
by(final_data$SPEAR, final_data$Country, min)# minimum
by(final_data$SPEAR, final_data$Country, max)# maximum

# for overview Table - range of TU values:
by(Effectdat$TU, Effectdat$Country, min)# minimum
by(Effectdat$TU, Effectdat$Country, max)# maximum


# SPEAR - TUmax relationship using new data:

#FR)
#new data
summary.lm(model_fr <- lm(SPEAR ~ logTU_Min_max + Recovery, data= final_data[final_data$Country=="FR", ])) 
# r2 = 0.77, recovery significant at 0.08

plot(final_data$logTU_Min_max[final_data$Country=="FR"], final_data$SPEAR[final_data$Country=="FR"], xlab="maxTU new", ylab="SPEAR", main="France")
abline(coefficients(model_fr)[1], coefficients(model_fr)[2])
abline(coefficients(model_fr)[1]+coefficients(model_fr)[3] , coefficients(model_fr)[2])

#DK)
#new data
summary.lm(model_dk <- lm(SPEAR ~ logTU_Min_sum, data= final_data[final_data$Country=="DK", ]))	
	# r2 = 0.68
plot(final_data$logTU_Min_sum[final_data$Country=="DK"], final_data$SPEAR[final_data$Country=="DK"], xlab="maxTU new", ylab="SPEAR", main="Denmark")
abline(model_dk)

#GR)
#new data
summary.lm(model_gr <- lm(SPEAR ~ logTU_Min_max + Recovery, data= final_data[final_data$Country=="GR", ]))	
	# r2 = 0.73, recovery significant at p=0.07
plot(final_data$logTU_Min_max[final_data$Country=="GR"], final_data$SPEAR[final_data$Country=="GR"], xlab="maxTU new", ylab="SPEAR", main="Germany")
abline(coefficients(model_gr)[1], coefficients(model_gr)[2])
abline(coefficients(model_gr)[1]+coefficients(model_gr)[3] , coefficients(model_gr)[2])


#ESP)
#new data
summary.lm(model_esp <- lm(SPEAR ~ log_msPAF_HC50, data= final_data[final_data$Country=="ESP", ]))
#r2 = 0.9

plot(final_data$log_msPAF_HC50[final_data$Country=="ESP"], final_data$SPEAR[final_data$Country=="ESP"], xlab="maxTU new", ylab="SPEAR", main="Spain")
abline(model_esp)


#AUS)
#new data
summary.lm(model_aus<- lm(SPEAR ~ logTU_HC5_sum + Recovery, data= final_data[final_data$Country=="OZ", ]))
	#r2 = 0.69

par(mfrow=c(2,2))
plot(model_aus)
	# site 12 strong outlier (row 82)

summary.lm(model_aus<- lm(SPEAR ~ logTU_HC5_sum + Recovery, data= final_data[row.names(final_data) != "82" & final_data$Country=="OZ", ]))
	# r2 = 0.81, outlier removed (see Schäfer et al. 2011)

plot(final_data$logTU_HC5_sum[final_data$Country=="OZ"], final_data$SPEAR[final_data$Country=="OZ"], xlab="maxTU new", ylab="SPEAR", main="Oz")
abline(coefficients(model_aus)[1], coefficients(model_aus)[2])
abline(coefficients(model_aus)[1]+ coefficients(model_aus)[3] , coefficients(model_aus)[2])
